==> 0.0.3.tar.gz: example/lib/tiktok.dart <==
import 'package:eyflutter_tik_video/eyflutter_tik_video.dart';
import 'package:eyflutter_uikit/eyflutter_uikit.dart';
import 'package:flutter/material.dart';

class TikTok extends StatefulWidget {
  const TikTok({Key? key}) : super(key: key);

  @override
  _TikTokState createState() => _TikTokState();
}

class _TikTokState extends LifecycleState<TikTok> {
  @override
  String get viewName => "tikVideoListTab";

  @override
  Widget build(BuildContext context) {
    super.build(context);
    return VideoListTabView(
      tabs: [
        VideoTikTab(tabName: "男", tag: "male"),
        VideoTikTab(tabName: "女", tag: "female"),
      ],
      pageCreated: onPageCreated,
    );
  }

  void onPageCreated(VideoTikTab tikTab, VideoTikListModel model) {
    var dataList = fetchVideo();
    // var dataList = getDataList(tikTab);
    model.appendVideos(dataList);
    model.notifierLazy();
  }

  List<VideoTikEntry> getDataList(VideoTikTab tikTab) {
    List<VideoTikEntry> items = [];
    if (tikTab.tag == "male") {
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/205/61608657123803205.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/365/61605149477175365.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/373/61605149446242373.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/133/61605148670296133.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/741/61605147761180741.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/181/61605146780762181.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/773/61605145441992773.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/829/61605145061621829.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/605/61605141635137605.mp4"));
    } else if (tikTab.tag == "female") {
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/653/61608623868739653.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/917/61608623863758917.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/325/61608623859040325.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/837/61608623845408837.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/389/61608623840952389.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/997/61608623816572997.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/237/61608623806087237.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/69/61608623669248069.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/925/61608623636217925.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/293/61608623524020293.mp4"));
    }
    return items;
  }

  static List<VideoTikEntry> fetchVideo() {
    List<VideoTikEntry> list = [];
    list.add(VideoTikEntry(videoUrl: "https://v-cdn.zjol.com.cn/276982.mp4", autoPlay: true));
    list.add(VideoTikEntry(videoUrl: "https://v-cdn.zjol.com.cn/276984.mp4"));
    list.add(VideoTikEntry(videoUrl: "https://v-cdn.zjol.com.cn/276985.mp4"));
    list.add(VideoTikEntry(videoUrl: "http://vfx.mtime.cn/Video/2019/03/19/mp4/190319222227698228.mp4"));
    list.add(VideoTikEntry(videoUrl: "http://vfx.mtime.cn/Video/2019/03/19/mp4/190319222227698228.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/205/61608657123803205.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/365/61605149477175365.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/373/61605149446242373.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/133/61605148670296133.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/741/61605147761180741.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/181/61605146780762181.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/773/61605145441992773.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/829/61605145061621829.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/605/61605141635137605.mp4"));
    return list;
  }
}

==> 0.0.5.tar.gz: example/lib/tiktok.dart <==
import 'package:eyflutter_tik_video/eyflutter_tik_video.dart';
import 'package:eyflutter_uikit/eyflutter_uikit.dart';
import 'package:flutter/material.dart';

class TikTok extends StatefulWidget {
  const TikTok({Key? key}) : super(key: key);

  @override
  _TikTokState createState() => _TikTokState();
}

class _TikTokState extends LifecycleState<TikTok> {
  @override
  String get viewName => "tikVideoListTab";

  @override
  Widget build(BuildContext context) {
    super.build(context);
    return SafeArea(
      child: VideoListTabView(
        tabs: [
          VideoTikTab(tabName: "帅哥", tag: "male"),
          VideoTikTab(tabName: "美女", tag: "female"),
        ],
        pageCreated: onPageCreated,
        nextPage: (VideoTikTab tikTab) {},
      ),
      top: true,
    );
  }

  void onPageCreated(VideoTikTab tikTab, VideoTikListModel model) {
    var dataList = fetchVideo();
    // var dataList = getDataList(tikTab);
    model.appendVideos(dataList);
    model.notifierLazy();
  }

  List<VideoTikEntry> getDataList(VideoTikTab tikTab) {
    List<VideoTikEntry> items = [];
    if (tikTab.tag == "male") {
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/205/61608657123803205.mp4", autoPlay: true));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/365/61605149477175365.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/373/61605149446242373.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/133/61605148670296133.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/741/61605147761180741.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/181/61605146780762181.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/773/61605145441992773.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/829/61605145061621829.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/605/61605141635137605.mp4"));
    } else if (tikTab.tag == "female") {
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/653/61608623868739653.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/917/61608623863758917.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/325/61608623859040325.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/837/61608623845408837.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/389/61608623840952389.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/997/61608623816572997.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/237/61608623806087237.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/69/61608623669248069.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/925/61608623636217925.mp4"));
      items.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/293/61608623524020293.mp4"));
    }
    return items;
  }

  static List<VideoTikEntry> fetchVideo() {
    List<VideoTikEntry> list = [];
    list.add(VideoTikEntry(videoUrl: "https://v-cdn.zjol.com.cn/276982.mp4", autoPlay: true));
    list.add(VideoTikEntry(videoUrl: "https://v-cdn.zjol.com.cn/276984.mp4"));
    list.add(VideoTikEntry(videoUrl: "https://v-cdn.zjol.com.cn/276985.mp4"));
    list.add(VideoTikEntry(videoUrl: "http://vfx.mtime.cn/Video/2019/03/19/mp4/190319222227698228.mp4"));
    list.add(VideoTikEntry(videoUrl: "http://vfx.mtime.cn/Video/2019/03/19/mp4/190319222227698228.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/205/61608657123803205.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/365/61605149477175365.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/373/61605149446242373.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/133/61605148670296133.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/741/61605147761180741.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/181/61605146780762181.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/773/61605145441992773.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/829/61605145061621829.mp4"));
    // list.add(VideoTikEntry(videoUrl: "https://v.kexiu.xyz/videos/605/61605141635137605.mp4"));
    return list;
  }
}
